.. _tutorials-index:

===========
 Tutorials
===========

.. htmlonly::

    :Release: |version|
    :Date: |today|

.. _tutorials-index-intro:

Introductory
------------

.. toctree::
    :maxdepth: 2

    pyplot_tutorial.rst
    image_tutorial.rst
    gridspec.rst
    tight_layout_guide.rst

.. _tutorials-index-inter:

Intermediate
------------
.. toctree::
   :maxdepth: 2

   artists.rst
   legend_guide.rst

.. _tutorials-index-adv:

Advanced
--------

.. toctree::
   :maxdepth: 2

   transforms_tutorial.rst
   path_tutorial.rst
   patheffects_guide.rst
